% The class MatchWordStringKernel computes a variant of the polynomial
% kernel on strings of same length converted to a word alphabet.
% 
% It is computed as
% 
% k(x,x')= \sum_{i=0}^L I(x_i=x'_i)+c)^d
% 
% where I is the indicator function which evaluates to 1 if its argument is
% true and to 0 otherwise.
% 
% Note that additional normalisation is applied, i.e.
%     k'(x, x')=\frac{k(x, x')}{\sqrt{k(x, x)k( x', x')}}
% 

modshogun

addpath('tools');
fm_train_dna=load_matrix('../data/fm_train_dna.dat');
fm_test_dna=load_matrix('../data/fm_test_dna.dat');

% match_word_string
disp('MatchWordString')

order=4;
gap=0;
reverse=false;
degree=3;
scale=1.4;
size_cache=10;

charfeat=StringCharFeatures(DNA);
charfeat.set_features(fm_train_dna);
feats_train=StringWordFeatures(charfeat.get_alphabet());
feats_train.obtain_from_char(charfeat, order-1, order, gap, reverse);
preproc=SortWordString();
preproc.init(feats_train);
feats_train.add_preprocessor(preproc);
feats_train.apply_preprocessor();

charfeat=StringCharFeatures(DNA);
charfeat.set_features(fm_test_dna);
feats_test=StringWordFeatures(charfeat.get_alphabet());
feats_test.obtain_from_char(charfeat, order-1, order, gap, reverse);
feats_test.add_preprocessor(preproc);
feats_test.apply_preprocessor();

kernel=MatchWordStringKernel(size_cache, degree);
kernel.set_normalizer(AvgDiagKernelNormalizer(scale));
kernel.init(feats_train, feats_train);

km_train=kernel.get_kernel_matrix();
kernel.init(feats_train, feats_test);
km_test=kernel.get_kernel_matrix();

